/*
 ==============================================================================
      Module Name : BiosIf.c
      Language    : SH-C Ver 4.1
      Function    : BLC-100 BIOS CALL INTERFACE
      History     :
       Date        Ver   Description
       ----------  ----  ------------------------------------------------
       1998/11/04  0.01  New Creation
       1998/11/27  0.02  Add Function 'TimeWait'
       1999/02/05  0.03  Add Function 'BiosInit'
       1999/02/08  0.04  Add Parameter to 'Reset'
       1999/02/12  0.05  Add Debug I/F
                         Capslize pid
       1999/03/09  0.06  Add Function 'GetVer'
       1999/08/24  0.07  Add Function 'LedCtrl' and 'LedCtrlAll'
       2000/02/07  0.08  Add Function for 'DhcpReq'
       2000/06/28  0.09  'PutMsg'̒ǉ
       2000/09/12  0.10  'GetMacAddr'̒ǉ


 ==============================================================================
*/

#include	<string.h>

#include	"BiosIf.h"

static	int	pid;						/* vZXID           */
static	int	debugpid;					/* fobOpvZXID */

/*****  BIOS̏  ********************************************************/
void B_Init(int aPid)
{
	pid = aPid;
}

/*****  ^C}Rg[  **************************************************/
int TmStart()
{
	return trapa_svc(0x20, pid);
}

int TmGet(int no, unsigned int *value)
{
	return trapa_svc(0x21, pid, no, value);
}

int TmStop(int no)
{
	return trapa_svc(0x22, pid, no);
}

/*****  XCb`擾  ********************************************************/
int GetSw(int flg)
{
	return trapa_svc(0x23, pid, flg);
}

/*****  v  ****************************************************************/
int GetTime(unsigned char *dtime)
{
	return trapa_svc(0x24, pid, dtime);
}

int SetTime(unsigned char *dtime)
{
	return trapa_svc(0x25, pid, dtime);
}

int SetAlarm(unsigned char *alarm)
{
	return trapa_svc(0x26, pid, alarm);
}

int SetAlarmInt(int *vect, int flg)
{
	return trapa_svc(0x27, pid, vect, flg);
}

/*****  p[^  ******************************************************/
int GetParam(int *param, int flg)
{
	return trapa_svc(0x28, pid, param, flg);
}

int SetParam(int *param, int flg)
{
	return trapa_svc(0x29, pid, param, flg);
}

/*****  荞݃xN^  ******************************************************/
int GetVect(int vect, int trp, void *(*func)(void))
{
	return trapa_svc(0x2a, pid, vect, trp, func);
}

int SetVect(int vect, int trp, void (*func)(void))
{
	return trapa_svc(0x2b, pid, vect, trp, func);
}

/*****  IǗ  ******************************************************/
int Malloc(int size, void ***addr)
{
	return trapa_svc(0x2c, pid, size, addr);
}

int Free(void **addr)
{
	return trapa_svc(0x2d, pid, addr);
}

/*****  bZ[W  **********************************************************/
int PutMsg(int *msg)
{
	((TMsg *)msg)->src = (short)pid;
	return trapa_svc(0x2e, pid, msg);
}
int GetMsg(int *msg)
{
	((TMsg *)msg)->src = (short)pid;
	return trapa_svc(0x2f, pid, msg);
}
int PeekMsg(int sw)
{
	return trapa_svc(0x3f, pid, sw);
}

/*****  [UvO  ****************************************************/
int Exec(char *prog)
{
	return trapa_svc(0x30, pid, prog);
}

int Kill(int prcs)
{
	return trapa_svc(0x31, pid, prcs);
}

int TimeWait(int tim)
{
	return trapa_svc(0x32, pid, tim);
}

int GetPid(char *prog)
{
	return trapa_svc(0x33, pid, prog);
}

/*****  tbV  ****************************************************/
int PmErase(int sa)
{
	return trapa_svc(0x34, pid, sa);
}

int PmWrite(int sa, short *data, int size)
{
	return trapa_svc(0x35, pid, sa, data, size);
}

int PmRead(int sa, short *data, int size)
{
	return trapa_svc(0x36, pid, sa, data, size);
}

int WriteProgram(void *prog)
{
	return trapa_svc(0x37, pid, prog);
}

int EraseProgram(char *prog)
{
	return trapa_svc(0x38, pid, prog);
}

void Reset(int sw)
{
	trapa_svc(0x39, pid, sw);
}

int GetVer(void)
{
	return trapa_svc(0x3a, pid);
}

int LedCtrl(int led, int flg)
{
	return trapa_svc(0x3b, pid, led, flg);
}

int LedCtrlAll(Byte *flgs)
{
	return trapa_svc(0x3c, pid, flgs);
}

int GetUsrPrm(short *param, int flg, int size)
{
	return trapa_svc(0x3d, pid, param, flg, size);
}

int SetUsrPrm(short *param, int flg, int size)
{
	return trapa_svc(0x3e, pid, param, flg, size);
}

/*****  RS-232C  *************************************************************/
int RsOpen(int *rsparam)
{
	return trapa_svc(0x40, pid, rsparam);
}

int RsClose()
{
	return trapa_svc(0x41, pid);
}

int RsSend(char *data, int size)
{
	return trapa_svc(0x42, pid, data, size);
}

int RsRecv(char *data, int *size)
{
	return trapa_svc(0x43, pid, data, size);
}

int RsGetBuff(int *rvex, int *rvfr, int *sdex, int *sdfr)
{
	return trapa_svc(0x44, pid, rvex, rvfr, sdex, sdfr);
}

void RsFlushRecv()
{
	trapa_svc(0x45, pid);
}

void RsFlushSend()
{
	trapa_svc(0x46, pid);
}

int RsGetCtrl()
{
	return trapa_svc(0x47, pid);
}

int RsSetCtrl(int ctrl, int sw)
{
	return trapa_svc(0x48, pid, ctrl, sw);
}

int RsOpenX(int *rsparam)
{
	return trapa_svc(0x49, pid, rsparam);
}

int RsCloseX()
{
	return trapa_svc(0x4a, pid);
}

int RsSetBreak(int tim)
{
	return trapa_svc(0x4b, pid, tim);
}

/*****  lbg[NC^tF[X  ******************************************/
int LanOpen()
{
	return trapa_svc(0x50, pid);
}

int LanClose()
{
	return trapa_svc(0x51, pid);
}

int Socket(int flg)
{
	return trapa_svc(0x52, pid, flg);
}

int Bind(int sck, unsigned long ip, unsigned short port)
{
	return trapa_svc(0x53, pid, sck, ip, port);
}

int Connect(int sck, unsigned long ip, unsigned short port, int flg)
{
	return trapa_svc(0x54, pid, sck, ip, port, flg);
}

int ConnectRes(int sck)
{
	return trapa_svc(0x55, pid, sck);
}

int Listen(int sck, int backlog)
{
	return trapa_svc(0x56, pid, sck, backlog);
}

int Accept(int sck, unsigned long *ip, unsigned short *port)
{
	return trapa_svc(0x57, pid, sck, ip, port);
}

int Send(int sck, char *data, int size)
{
	return trapa_svc(0x58, pid, sck, data, size);
}

int SendTo(int sck, char *data, int size, int *to)
{
	return trapa_svc(0x59, pid, sck, data, size, to);
}

int Recv(int sck, char *data, int size)
{
	return trapa_svc(0x5a, pid, sck, data, size);
}

int RecvFrom(int sck, char *data, int size, int *from)
{
	return trapa_svc(0x5b, pid, sck, data, size, from);
}

int LanGetBuff(int sck, int flg, int *exist, int *fre)
{
	return trapa_svc(0x5c, pid, sck, flg, exist, fre);
}

int Select(int cnt, unsigned char *fdset)
{
	return trapa_svc(0x5d, pid, cnt, fdset);
}

int Close(int sck)
{
	return trapa_svc(0x5e, pid, sck);
}

int Abort(int sck)
{
	return trapa_svc(0x5f, pid, sck);
}

int FlushRecvBuff(int sck)
{
	return trapa_svc(0x60, pid, sck);
}

int FlushSendBuff(int sck)
{
	return trapa_svc(0x61, pid, sck);
}

int Arp(unsigned long ip, unsigned char *mac)
{
	return trapa_svc(0x62, pid, ip, mac);
}

int Rarp(unsigned char *mac, unsigned long *ip)
{
	return trapa_svc(0x63, pid, mac, ip);
}

int Icmp(unsigned long ip, int tmout)
{
	return trapa_svc(0x64, pid, ip, tmout);
}

int DhcpReq(unsigned long *ipinfo, int tmout, int retry)
{
	return trapa_svc(0x65, pid, ipinfo, tmout, retry);
}

int GetMacAddr(unsigned char *mac)
{
	return trapa_svc(0x66, pid, mac);
}

/*****  fobOI/F  *********************************************************/
void TrInit()
{
	if((debugpid = Exec("TelnetSv")) == ERR_RUNNING)
		debugpid = GetPid("TelnetSv");
}

void TrOut(char *msgstr)
{
	TMsg	msg;

	if(debugpid == ERR_NOPROC)
		return;

	msg.dest   = (short)debugpid;
	msg.rqrs   = MSG_REQUEST;
	msg.cmd    = MSG_PUTDATA;
	msg.prmlen = (unsigned short)(strlen(msgstr) + 1);
	if(msg.prmlen > 4) {
		if(Malloc((int)msg.prmlen, (void ***)&msg.prm) != 1)
			return;
		strcpy(*msg.prm, msgstr);
	} else
		strcpy((char *)&msg.prm, msgstr);
	PutMsg((int *)&msg);
}
