/*
 ==============================================================================
      Module Name : BiosIf.h
      Language    : SH-C Ver 4.1
      Function    : BLC-100 BIOS CALL INTERFACE
      History     :
       Date        Ver   Description
       ----------  ----  ------------------------------------------------
       1998/11/04  0.01  New Creation
       1998/11/27  0.02  Add Function 'TimeWait'
       1998/12/09  0.03  Add Defines for FTP Server
       1998/12/24  0.04  Modify Constant of Error Message
       1999/01/07  0.05  Add Defines for MSG_GETSTAT
       1999/02/05  0.06  Add Function 'B_Init'
       1999/02/08  0.07  Add Parameter to 'Reset'
       1999/03/04  0.08  Add Defines MSG_APPENDFILE and MSG_CH_DIR
       1999/03/09  0.09  Add Function 'GetVer'
       1999/09/24  0.10  Add Function for LedCtrl
                         Add Defines
       2000/01/17  0.11  Add Function for 'RsOpenX' and 'RsCloseX'
       2000/02/07  0.12  Add Function for 'DhcpReq'
       2000/05/31  0.13  Add Define of MSG_RENFILE1 and MSG_RENFILE2
       2000/06/28  0.14  'PutMsg'̒ǉ
       2000/06/29  0.15  MSG_RENFILE, ERR_FTP_NOFILEdefineǉ
       2000/09/12  0.16  'GetMacAddr'̒ǉ
       2000/11/30  0.17  'RsSetBreak'̒ǉ

 ==============================================================================
*/
#ifndef	BIOSIF_H
#define	BIOSIF_H	1

#include	<umachine.h>

#define	Byte	unsigned char
#define	Word	unsigned short
#define	Dword	unsigned long

/*****  bZ[W\  ****************************************************/
typedef	struct	{
	short	  dest;						/* vZXID         */
	short	  src;						/* vZXID           */
	Byte	  rqrs;						/* v//G[       */
	Byte	  cmd;						/* R}hR[h         */
	Word	  prmlen;					/* p[^           */
	char	**prm;						/* p[^ւ̃|C^ */
} TMsg;

/*****  BIOS̏  ********************************************************/
void	B_Init(int);

/*****  ^C}Rg[  **************************************************/
int		TmStart(void);
int		TmGet(int, unsigned int *);
int		TmStop(int);

/*****  XCb`擾  ********************************************************/
int		GetSw(int);

/*****  v  ****************************************************************/
int		GetTime(Byte *);
int		SetTime(Byte *);
int		SetAlarm(Byte *);
int		SetAlarmInt(int *, int);

/*****  p[^  ******************************************************/
int		GetParam(int *, int);
int		SetParam(int *, int);
int		GetUsrPrm(short *, int, int);
int		SetUsrPrm(short *, int, int);

/*****  荞݃xN^  ******************************************************/
int		GetVect(int, int, void *(*)(void));
int		SetVect(int, int, void (*)(void));

/*****  IǗ  ******************************************************/
int		Malloc(int, void ***);
int		Free(void **);

/*****  bZ[W  **********************************************************/
int		PutMsg(int *);
int		GetMsg(int *);
int		PeekMsg(int);

/*****  [UvO  ****************************************************/
int		Exec(char *);
int		Kill(int);
int		TimeWait(int);
int		GetPid(char *);

/*****  tbV  ****************************************************/
int		PmErase(int);
int		PmWrite(int, short *, int);
int		PmRead(int, short *, int);
int		WriteProgram(void *);
int		EraseProgram(char *);

void	Reset(int);
int		GetVer(void);

/*****  LED  *****************************************************************/
int		LedCtrl(int, int);
int		LedCtrlAll(Byte *);

/*****  RS-232C  *************************************************************/
int		RsOpen(int *);
int		RsClose(void);
int		RsSend(char *, int);
int		RsRecv(char *, int *);
int		RsGetBuff(int *, int *, int *, int *);
void	RsFlushRecv(void);
void	RsFlushSend(void);
int		RsGetCtrl(void);
int		RsSetCtrl(int, int);
int		RsOpenX(int *);
int		RsCloseX(void);
int		RsSetBreak(int);

/*****  lbg[NC^tF[X  ******************************************/
int		LanOpen(void);
int		LanClose(void);
int		Socket(int);
int		Bind(int, Dword, Word);
int		Connect(int, Dword, Word, int);
int		ConnectRes(int);
int		Listen(int, int);
int		Accept(int, Dword *, Word *);
int		Send(int, char *, int);
int		SendTo(int, char *, int, int *);
int		Recv(int, char *, int);
int		RecvFrom(int, char *, int, int *);
int		LanGetBuff(int, int, int *, int *);
int		Select(int, Byte *);
int		Close(int);
int		Abort(int);
int		FlushRecvBuff(int);
int		FlushSendBuff(int);
int		Arp(Dword, Byte *);
int		Rarp(Byte *, Dword *);
int		Icmp(Dword, int);
int		DhcpReq(Dword *, int, int);
int		GetMacAddr(unsigned char *);

/*****  fobOC^tF[X  **********************************************/
void	TrInit(void);
void	TrOut(char *);

#define	OK				1
#define	NG				-1

#define	TRUE			1
#define	FALSE			0

#define	ON				1
#define	OFF				0
#define	SLOW			2
#define	FAST			3

#define	LED1			0
#define	LED2			1
#define	LED3			2
#define	LED4			3

#define	C_NULL			(char)0x00

/*****  G[R[h`  ****************************************************/
#define	ERR_PARAM		(int)0xf0000000	/* p[^G[           */
#define	ERR_PID			(int)0xf0000001	/* PIDG[                  */
#define	ERR_INUSE		(int)0xf0000002	/* Ŏgp           */
#define	ERR_RUNNING		(int)0xf0000003	/* łɎs               */
#define	ERR_NOPROC		(int)0xf0000004	/* vZXȂ             */
#define	ERR_PGNOTFOUND	(int)0xf0000005	/* vOȂ   */
#define	ERR_NOOTHER		(int)0xf0000006	/* ɃvZX݂Ȃ   */
#define	ERR_QUEFULL		(int)0xf0000007	/* bZ[WL[ɒǉs */

#define	ERR_MEMOVER		(int)0xa0000000	/* s                 */
#define	ERR_FLSHWRT		(int)0xa0000001	/* tbV݃G[   */
#define	ERR_PGMEMOVER	(int)0xa0000002	/* vOi[Ȃ       */

#define	ERR_RSOPENED	(int)0x90000000	/* RS-232CI[vς        */
#define	ERR_RSCLOSED	(int)0x90000001	/* RS-232CI[v          */
#define	ERR_RSFULL		(int)0x90000002	/* RS-232CMobt@t    */
#define	ERR_RSORER		(int)0x90000003	/* RS-232CI[oG[    */
#define	ERR_RSFER		(int)0x90000004	/* RS-232Ct[~OG[  */
#define	ERR_RSPER		(int)0x90000005	/* RS-232CpeBG[      */
#define	ERR_RSSDEXIST	(int)0x90000006	/* RS-232CMf[^      */

#define	ERR_LANOPENED	(int)0x81000007	/* LANI[vς            */
#define	ERR_LANCLOSED	(int)0x81000008	/* LANI[v              */
#define	ERR_BOUND		(int)0x84000001	/* \PbgBindς         */
#define	ERR_NOBUFS		(int)0x84000002	/* \Pbge[ut     */
#define	ERR_NOSOCKET	(int)0x84000003	/* \Pbg쐬             */
#define	ERR_OPENED		(int)0x84050004	/* \PbgI[vς       */
#define	ERR_NOTBOUND	(int)0x84050005	/* \PbgBind             */
#define	ERR_NETUNREACH	(int)0x84050006	/* ĐɓBłȂ       */
#define	ERR_TIMEDOUT    (int)0x84050007	/* ڑ^CAEg           */
#define	ERR_ADDRINUSE	(int)0x84050008	/* AhXgp           */
#define	ERR_NOTCONN		(int)0x84050009	/* ڑĂȂ           */
#define	ERR_MFILE		(int)0x8405000a	/* ANZvgG[           */
#define	ERR_EXISTDATA	(int)0x8405000b	/* ̃f[^       */
#define	ERR_NOTUDP		(int)0x8405000c	/* UDP\PbgłȂ          */
#define	ERR_CONNREFUSED	(int)0x8405000d	/* ڑۂꂽ           */
#define	ERR_LISTENING	(int)0x8405000e	/* łɐڑvt\   */
#define	ERR_CONNECTING	(int)0x8405000f	/* \Pbg͐ڑv       */
#define	ERR_NOTTCP		(int)0x84060000	/* TCP\PbgłȂ          */
#define	ERR_FTP_LOGIN	(int)0x85000000	/* FTPOCG[          */
#define	ERR_FTP_PASSWD	(int)0x85000001	/* FTPpX[hG[        */
#define	ERR_FTP_BINARY	(int)0x85000002	/* FTPoCi]G[      */
#define	ERR_DELFILE		(int)0x85000003	/* FTPt@C폜G[      */
#define	ERR_CH_DIR		(int)0x85000004	/* FTPfBNgύXG[  */
#define	ERR_FTP_IRESP	(int)0x85000005	/* FTPX|Xُ          */
#define	ERR_FTP_NOFILE	(int)0x85000006	/* FTPt@CȂG[      */

/*****  bZ[W萔̒`  ************************************************/
#define	MSG_REQUEST		(Byte)0	/* v   */
#define	MSG_RESPONSE	(Byte)1	/*    */
#define	MSG_ERROR		(Byte)2	/* G[ */

#define	MSG_SYSMSG		(Byte)0			/* J[l̃bZ[W */
#define	MSG_PUTDATA		(Byte)1			/* f[^ʒm         */
#define	MSG_GETDATA		(Byte)2			/* f[^擾         */
#define	MSG_PUTSTAT		(Byte)3			/* Ԓʒm           */
#define	MSG_GETSTAT		(Byte)4			/* Ԏ擾           */
#define	MSG_SVOPEN		(Byte)5			/* T[oI[vv */
#define	MSG_SVCLOSE		(Byte)6			/* T[oN[Yv */
#define	MSG_CONNECT		(Byte)7			/* ڑv           */
#define	MSG_CONNECTED	(Byte)8			/* ڑʒm       */
#define	MSG_CONNCLOSE	(Byte)9			/* ڑؒfv       */
#define	MSG_CONNCLOSED	(Byte)10		/* ڑؒfʒm       */
#define	MSG_SVOPENED	(Byte)11		/* T[oI[vʒm */
#define	MSG_SVCLOSED	(Byte)12		/* T[oN[Yʒm */
#define	MSG_PUTFILE		(Byte)13		/* t@Cʒm   */
#define	MSG_GETFILE		(Byte)14		/* t@Cv       */
#define	MSG_BUFFULL		(Byte)15		/* obt@tʒm   */
#define	MSG_BUFREADY	(Byte)16		/* obt@fBʒm */
#define	MSG_LSTFILE		(Byte)17		/* t@Cꗗv   */
#define	MSG_ENDFILE		(Byte)18		/* t@CIʒm   */
#define	MSG_DELFILE		(Byte)19		/* t@C폜v   */
#define	MSG_APPENDFILE	(Byte)20		/* t@Cǉʒm     */
#define	MSG_CH_DIR		(Byte)21		/* fBNgύXv */
#define	MSG_PUTLOG		(Byte)24		/* Oʒm             */

#define	ERR_SRCPID		(Byte)0x80		/* 茳vZXs       */
#define	ERR_MSGCMD		(Byte)0x81		/* R}hs             */
#define	ERR_PARAMLEN	(Byte)0x82		/* p[^ُ           */
#define	ERR_PARAMDATA	(Byte)0x83		/* p[^f[^ُ       */
#define	ERR_READONLY	(Byte)0x84		/* ǎpԂŏݕs */
#define	ERR_INVALIDSTAT	(Byte)0x85		/* ԂsŃR}h */

#define	MSG_LATER		0				/* ŕω̏Ԃv */
#define	MSG_IMMEDIATE	1				/* ݂̏Ԃv       */
#define	MSG_STATSTR		2				/* ݂̏ԕv */

#endif	/* end of #ifndef BIOSIF_H */
